==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Arcs et les cercles</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>dans les segments de ligne (longueur fixe)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>dans les segments de ligne (angle fixe)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ellipses</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en polyligne comprenant des segments d&apos;arc</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en polyligne comprenant des segments de ligne</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Cotations</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en lignes, des solides et des textes</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translatorcomment>--google--
Dessine des hachures et des remplissages unis
&amp;Combiner hachures
Combiner hachures</translatorcomment>
        <translation>Trappes</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>dans les lignes</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>Blocs</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en entités</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>Décompos&amp;er</translation>
    </message>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Décomposer</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+133"/>
        <source>Spline segments:</source>
        <translation>Segments de spline :</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Segments de ellipse :</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Spline approximation tolerance:</source>
        <translation>Spline tolérance :</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Arcs et les cercles</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>dans les segments de ligne (longueur fixe)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>dans les segments de ligne (angle fixe)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ellipses</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en polyligne comprenant des segments d&apos;arc</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en polyligne comprenant des segments de ligne</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Cotations</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en lignes, des solides et des textes</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translatorcomment>--google--
Dessine des hachures et des remplissages unis
&amp;Combiner hachures
Combiner hachures</translatorcomment>
        <translation>Trappes</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>dans les lignes</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>Blocs</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>en entités</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>Décompos&amp;er</translation>
    </message>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Décomposer</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+197"/>
        <source>Explode text glyphs to polylines</source>
        <translation>Décomposer contours de texte en polylignes</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spline segments:</source>
        <translation>Segments de spline :</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Segments de ellipse :</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Explode splines to polylines with line segments</source>
        <translation>Décomposer splines aux polylignes avec des segments de ligne</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Explode multiline texts into multiple simple text blocks</source>
        <translation>Décomposer texte multiligne dans plusieurs blocs de texte simple</translation>
    </message>
    <message>
        <location line="-31"/>
        <source>Spline approximation tolerance:</source>
        <translation>Spline tolérance :</translation>
    </message>
</context>
</TS>
